# Changelog

## 1.0.0 (2024-10-07)

Full Changelog: [v0.0.1-alpha.0...v1.0.0](https://github.com/spi-tch/spitch-python/compare/v0.0.1-alpha.0...v1.0.0)

### Features

* **api:** update via SDK Studio ([41dd345](https://github.com/spi-tch/spitch-python/commit/41dd34562573b2d2807cedc4722c53b7350ef4dc))
* **api:** update via SDK Studio ([#10](https://github.com/spi-tch/spitch-python/issues/10)) ([74819f2](https://github.com/spi-tch/spitch-python/commit/74819f278e9e2bfa4bb3f5d06c59c3fda3ed069f))
* **api:** update via SDK Studio ([#4](https://github.com/spi-tch/spitch-python/issues/4)) ([22bbf05](https://github.com/spi-tch/spitch-python/commit/22bbf059f4f95bd1f5e99e5d4d71df73977eb17b))
* **api:** update via SDK Studio ([#5](https://github.com/spi-tch/spitch-python/issues/5)) ([a97e4d7](https://github.com/spi-tch/spitch-python/commit/a97e4d77f0bcc97f1b222d1a8500901273b56f9a))
* **api:** update via SDK Studio ([#6](https://github.com/spi-tch/spitch-python/issues/6)) ([b650ea2](https://github.com/spi-tch/spitch-python/commit/b650ea223e9c2e87e0c1a8f9e904a889686decc2))
* **api:** update via SDK Studio ([#7](https://github.com/spi-tch/spitch-python/issues/7)) ([3956108](https://github.com/spi-tch/spitch-python/commit/39561080f65b7098a2bd7851159a0a1ac2bd1b5e))
* **api:** update via SDK Studio ([#8](https://github.com/spi-tch/spitch-python/issues/8)) ([75481cc](https://github.com/spi-tch/spitch-python/commit/75481cc5cc576e2a16e056bdd885def8cad0060d))
* **api:** update via SDK Studio ([#9](https://github.com/spi-tch/spitch-python/issues/9)) ([3a43e4f](https://github.com/spi-tch/spitch-python/commit/3a43e4f9c97e5afeaa8374c2eafa815e26d85680))


### Chores

* go live ([#1](https://github.com/spi-tch/spitch-python/issues/1)) ([46370f0](https://github.com/spi-tch/spitch-python/commit/46370f02575812eda0c2dcd53a007375720fea97))
* update SDK settings ([#3](https://github.com/spi-tch/spitch-python/issues/3)) ([a9af774](https://github.com/spi-tch/spitch-python/commit/a9af774f183fdf2b50684adf5714c6b5e5354653))
